# coding: utf-8

"""
    Webhooks Webhooks

    Provides a way for apps to subscribe to certain change events in HubSpot. Once configured, apps will receive event payloads containing details about the changes at a specified target URL. There can only be one target URL for receiving event notifications per app.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.webhooks.api_client import ApiClient
from hubspot.webhooks.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class SubscriptionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, subscription_id, app_id, **kwargs):  # noqa: E501
        """Delete event subscription  # noqa: E501

        Delete an existing event subscription by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(subscription_id, app_id, async_req=True)
        >>> result = thread.get()

        :param subscription_id: The ID of the event subscription. (required)
        :type subscription_id: int
        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(subscription_id, app_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, subscription_id, app_id, **kwargs):  # noqa: E501
        """Delete event subscription  # noqa: E501

        Delete an existing event subscription by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(subscription_id, app_id, async_req=True)
        >>> result = thread.get()

        :param subscription_id: The ID of the event subscription. (required)
        :type subscription_id: int
        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["subscription_id", "app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and local_var_params.get("subscription_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscription_id` when calling `archive`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in local_var_params:
            path_params["subscriptionId"] = local_var_params["subscription_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/webhooks/v3/{appId}/subscriptions/{subscriptionId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, app_id, subscription_create_request, **kwargs):  # noqa: E501
        """Create an event subscription  # noqa: E501

        Create new event subscription for the specified app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(app_id, subscription_create_request, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param subscription_create_request: (required)
        :type subscription_create_request: SubscriptionCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SubscriptionResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(app_id, subscription_create_request, **kwargs)  # noqa: E501

    def create_with_http_info(self, app_id, subscription_create_request, **kwargs):  # noqa: E501
        """Create an event subscription  # noqa: E501

        Create new event subscription for the specified app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(app_id, subscription_create_request, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param subscription_create_request: (required)
        :type subscription_create_request: SubscriptionCreateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SubscriptionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id", "subscription_create_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'subscription_create_request' is set
        if self.api_client.client_side_validation and local_var_params.get("subscription_create_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscription_create_request` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "subscription_create_request" in local_var_params:
            body_params = local_var_params["subscription_create_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            201: "SubscriptionResponse",
        }

        return self.api_client.call_api(
            "/webhooks/v3/{appId}/subscriptions",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, app_id, **kwargs):  # noqa: E501
        """Read event subscriptions  # noqa: E501

        Retrieve event subscriptions for the specified app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SubscriptionListResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(app_id, **kwargs)  # noqa: E501

    def get_all_with_http_info(self, app_id, **kwargs):  # noqa: E501
        """Read event subscriptions  # noqa: E501

        Retrieve event subscriptions for the specified app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(app_id, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SubscriptionListResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_all`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "SubscriptionListResponse",
        }

        return self.api_client.call_api(
            "/webhooks/v3/{appId}/subscriptions",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, subscription_id, app_id, **kwargs):  # noqa: E501
        """Read an event subscription  # noqa: E501

        Retrieve a specific event subscription by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(subscription_id, app_id, async_req=True)
        >>> result = thread.get()

        :param subscription_id: The ID of the event subscription. (required)
        :type subscription_id: int
        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SubscriptionResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(subscription_id, app_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, subscription_id, app_id, **kwargs):  # noqa: E501
        """Read an event subscription  # noqa: E501

        Retrieve a specific event subscription by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(subscription_id, app_id, async_req=True)
        >>> result = thread.get()

        :param subscription_id: The ID of the event subscription. (required)
        :type subscription_id: int
        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SubscriptionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["subscription_id", "app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and local_var_params.get("subscription_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscription_id` when calling `get_by_id`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in local_var_params:
            path_params["subscriptionId"] = local_var_params["subscription_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "SubscriptionResponse",
        }

        return self.api_client.call_api(
            "/webhooks/v3/{appId}/subscriptions/{subscriptionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, subscription_id, app_id, subscription_patch_request, **kwargs):  # noqa: E501
        """Update an event subscription  # noqa: E501

        Update an existing event subscription by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(subscription_id, app_id, subscription_patch_request, async_req=True)
        >>> result = thread.get()

        :param subscription_id: The ID of the event subscription. (required)
        :type subscription_id: int
        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param subscription_patch_request: (required)
        :type subscription_patch_request: SubscriptionPatchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: SubscriptionResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(subscription_id, app_id, subscription_patch_request, **kwargs)  # noqa: E501

    def update_with_http_info(self, subscription_id, app_id, subscription_patch_request, **kwargs):  # noqa: E501
        """Update an event subscription  # noqa: E501

        Update an existing event subscription by ID.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(subscription_id, app_id, subscription_patch_request, async_req=True)
        >>> result = thread.get()

        :param subscription_id: The ID of the event subscription. (required)
        :type subscription_id: int
        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param subscription_patch_request: (required)
        :type subscription_patch_request: SubscriptionPatchRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(SubscriptionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["subscription_id", "app_id", "subscription_patch_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'subscription_id' is set
        if self.api_client.client_side_validation and local_var_params.get("subscription_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscription_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'subscription_patch_request' is set
        if self.api_client.client_side_validation and local_var_params.get("subscription_patch_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `subscription_patch_request` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "subscription_id" in local_var_params:
            path_params["subscriptionId"] = local_var_params["subscription_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "subscription_patch_request" in local_var_params:
            body_params = local_var_params["subscription_patch_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "SubscriptionResponse",
        }

        return self.api_client.call_api(
            "/webhooks/v3/{appId}/subscriptions/{subscriptionId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update_batch(self, app_id, batch_input_subscription_batch_update_request, **kwargs):  # noqa: E501
        """Batch create event subscriptions  # noqa: E501

        Batch create event subscriptions for the specified app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_batch(app_id, batch_input_subscription_batch_update_request, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param batch_input_subscription_batch_update_request: (required)
        :type batch_input_subscription_batch_update_request: BatchInputSubscriptionBatchUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: BatchResponseSubscriptionResponse
        """
        kwargs["_return_http_data_only"] = True
        return self.update_batch_with_http_info(app_id, batch_input_subscription_batch_update_request, **kwargs)  # noqa: E501

    def update_batch_with_http_info(self, app_id, batch_input_subscription_batch_update_request, **kwargs):  # noqa: E501
        """Batch create event subscriptions  # noqa: E501

        Batch create event subscriptions for the specified app.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_batch_with_http_info(app_id, batch_input_subscription_batch_update_request, async_req=True)
        >>> result = thread.get()

        :param app_id: The ID of the app. (required)
        :type app_id: int
        :param batch_input_subscription_batch_update_request: (required)
        :type batch_input_subscription_batch_update_request: BatchInputSubscriptionBatchUpdateRequest
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(BatchResponseSubscriptionResponse, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["app_id", "batch_input_subscription_batch_update_request"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update_batch" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `update_batch`")  # noqa: E501
        # verify the required parameter 'batch_input_subscription_batch_update_request' is set
        if self.api_client.client_side_validation and local_var_params.get("batch_input_subscription_batch_update_request") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `batch_input_subscription_batch_update_request` when calling `update_batch`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "batch_input_subscription_batch_update_request" in local_var_params:
            body_params = local_var_params["batch_input_subscription_batch_update_request"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "BatchResponseSubscriptionResponse",
            207: "BatchResponseSubscriptionResponseWithErrors",
        }

        return self.api_client.call_api(
            "/webhooks/v3/{appId}/subscriptions/batch/update",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.automation.actions.configuration import Configuration


class InputFieldDefinition(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"is_required": "bool", "automation_field_type": "str", "type_definition": "FieldTypeDefinition", "supported_value_types": "list[str]"}

    attribute_map = {"is_required": "isRequired", "automation_field_type": "automationFieldType", "type_definition": "typeDefinition", "supported_value_types": "supportedValueTypes"}

    def __init__(self, is_required=None, automation_field_type=None, type_definition=None, supported_value_types=None, local_vars_configuration=None):  # noqa: E501
        """InputFieldDefinition - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._is_required = None
        self._automation_field_type = None
        self._type_definition = None
        self._supported_value_types = None
        self.discriminator = None

        self.is_required = is_required
        if automation_field_type is not None:
            self.automation_field_type = automation_field_type
        self.type_definition = type_definition
        if supported_value_types is not None:
            self.supported_value_types = supported_value_types

    @property
    def is_required(self):
        """Gets the is_required of this InputFieldDefinition.  # noqa: E501


        :return: The is_required of this InputFieldDefinition.  # noqa: E501
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """Sets the is_required of this InputFieldDefinition.


        :param is_required: The is_required of this InputFieldDefinition.  # noqa: E501
        :type is_required: bool
        """
        if self.local_vars_configuration.client_side_validation and is_required is None:  # noqa: E501
            raise ValueError("Invalid value for `is_required`, must not be `None`")  # noqa: E501

        self._is_required = is_required

    @property
    def automation_field_type(self):
        """Gets the automation_field_type of this InputFieldDefinition.  # noqa: E501


        :return: The automation_field_type of this InputFieldDefinition.  # noqa: E501
        :rtype: str
        """
        return self._automation_field_type

    @automation_field_type.setter
    def automation_field_type(self, automation_field_type):
        """Sets the automation_field_type of this InputFieldDefinition.


        :param automation_field_type: The automation_field_type of this InputFieldDefinition.  # noqa: E501
        :type automation_field_type: str
        """

        self._automation_field_type = automation_field_type

    @property
    def type_definition(self):
        """Gets the type_definition of this InputFieldDefinition.  # noqa: E501


        :return: The type_definition of this InputFieldDefinition.  # noqa: E501
        :rtype: FieldTypeDefinition
        """
        return self._type_definition

    @type_definition.setter
    def type_definition(self, type_definition):
        """Sets the type_definition of this InputFieldDefinition.


        :param type_definition: The type_definition of this InputFieldDefinition.  # noqa: E501
        :type type_definition: FieldTypeDefinition
        """
        if self.local_vars_configuration.client_side_validation and type_definition is None:  # noqa: E501
            raise ValueError("Invalid value for `type_definition`, must not be `None`")  # noqa: E501

        self._type_definition = type_definition

    @property
    def supported_value_types(self):
        """Gets the supported_value_types of this InputFieldDefinition.  # noqa: E501


        :return: The supported_value_types of this InputFieldDefinition.  # noqa: E501
        :rtype: list[str]
        """
        return self._supported_value_types

    @supported_value_types.setter
    def supported_value_types(self, supported_value_types):
        """Sets the supported_value_types of this InputFieldDefinition.


        :param supported_value_types: The supported_value_types of this InputFieldDefinition.  # noqa: E501
        :type supported_value_types: list[str]
        """
        allowed_values = ["STATIC_VALUE", "OBJECT_PROPERTY", "FIELD_DATA", "FETCHED_OBJECT_PROPERTY", "ENROLLMENT_EVENT_PROPERTY"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and not set(supported_value_types).issubset(set(allowed_values)):  # noqa: E501
            raise ValueError(
                "Invalid values for `supported_value_types` [{0}], must be a subset of [{1}]".format(  # noqa: E501
                    ", ".join(map(str, set(supported_value_types) - set(allowed_values))), ", ".join(map(str, allowed_values))  # noqa: E501
                )
            )

        self._supported_value_types = supported_value_types

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputFieldDefinition):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InputFieldDefinition):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Marketing Emails

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.emails.configuration import Configuration


class EmailStatisticsData(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"device_breakdown": "dict[str, dict[str, int]]", "qualifier_stats": "dict[str, dict[str, int]]", "counters": "dict[str, int]", "ratios": "dict[str, float]"}

    attribute_map = {"device_breakdown": "deviceBreakdown", "qualifier_stats": "qualifierStats", "counters": "counters", "ratios": "ratios"}

    def __init__(self, device_breakdown=None, qualifier_stats=None, counters=None, ratios=None, local_vars_configuration=None):  # noqa: E501
        """EmailStatisticsData - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._device_breakdown = None
        self._qualifier_stats = None
        self._counters = None
        self._ratios = None
        self.discriminator = None

        self.device_breakdown = device_breakdown
        self.qualifier_stats = qualifier_stats
        self.counters = counters
        self.ratios = ratios

    @property
    def device_breakdown(self):
        """Gets the device_breakdown of this EmailStatisticsData.  # noqa: E501

        Statistics by device.  # noqa: E501

        :return: The device_breakdown of this EmailStatisticsData.  # noqa: E501
        :rtype: dict[str, dict[str, int]]
        """
        return self._device_breakdown

    @device_breakdown.setter
    def device_breakdown(self, device_breakdown):
        """Sets the device_breakdown of this EmailStatisticsData.

        Statistics by device.  # noqa: E501

        :param device_breakdown: The device_breakdown of this EmailStatisticsData.  # noqa: E501
        :type device_breakdown: dict[str, dict[str, int]]
        """
        if self.local_vars_configuration.client_side_validation and device_breakdown is None:  # noqa: E501
            raise ValueError("Invalid value for `device_breakdown`, must not be `None`")  # noqa: E501

        self._device_breakdown = device_breakdown

    @property
    def qualifier_stats(self):
        """Gets the qualifier_stats of this EmailStatisticsData.  # noqa: E501

        Number of emails that were dropped and bounced.  # noqa: E501

        :return: The qualifier_stats of this EmailStatisticsData.  # noqa: E501
        :rtype: dict[str, dict[str, int]]
        """
        return self._qualifier_stats

    @qualifier_stats.setter
    def qualifier_stats(self, qualifier_stats):
        """Sets the qualifier_stats of this EmailStatisticsData.

        Number of emails that were dropped and bounced.  # noqa: E501

        :param qualifier_stats: The qualifier_stats of this EmailStatisticsData.  # noqa: E501
        :type qualifier_stats: dict[str, dict[str, int]]
        """
        if self.local_vars_configuration.client_side_validation and qualifier_stats is None:  # noqa: E501
            raise ValueError("Invalid value for `qualifier_stats`, must not be `None`")  # noqa: E501

        self._qualifier_stats = qualifier_stats

    @property
    def counters(self):
        """Gets the counters of this EmailStatisticsData.  # noqa: E501

        Counters like number of `sent`, `open` or `delivered`.  # noqa: E501

        :return: The counters of this EmailStatisticsData.  # noqa: E501
        :rtype: dict[str, int]
        """
        return self._counters

    @counters.setter
    def counters(self, counters):
        """Sets the counters of this EmailStatisticsData.

        Counters like number of `sent`, `open` or `delivered`.  # noqa: E501

        :param counters: The counters of this EmailStatisticsData.  # noqa: E501
        :type counters: dict[str, int]
        """
        if self.local_vars_configuration.client_side_validation and counters is None:  # noqa: E501
            raise ValueError("Invalid value for `counters`, must not be `None`")  # noqa: E501

        self._counters = counters

    @property
    def ratios(self):
        """Gets the ratios of this EmailStatisticsData.  # noqa: E501

        Ratios like `openratio` or `clickratio`  # noqa: E501

        :return: The ratios of this EmailStatisticsData.  # noqa: E501
        :rtype: dict[str, float]
        """
        return self._ratios

    @ratios.setter
    def ratios(self, ratios):
        """Sets the ratios of this EmailStatisticsData.

        Ratios like `openratio` or `clickratio`  # noqa: E501

        :param ratios: The ratios of this EmailStatisticsData.  # noqa: E501
        :type ratios: dict[str, float]
        """
        if self.local_vars_configuration.client_side_validation and ratios is None:  # noqa: E501
            raise ValueError("Invalid value for `ratios`, must not be `None`")  # noqa: E501

        self._ratios = ratios

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmailStatisticsData):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EmailStatisticsData):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CMS Site Search

    Use these endpoints for searching content on your HubSpot hosted CMS website(s).  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.cms.site_search.configuration import Configuration


class IndexedField(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"values": "list[object]", "name": "str", "value": "object", "metadata_field": "bool"}

    attribute_map = {"values": "values", "name": "name", "value": "value", "metadata_field": "metadataField"}

    def __init__(self, values=None, name=None, value=None, metadata_field=None, local_vars_configuration=None):  # noqa: E501
        """IndexedField - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._values = None
        self._name = None
        self._value = None
        self._metadata_field = None
        self.discriminator = None

        self.values = values
        self.name = name
        self.value = value
        self.metadata_field = metadata_field

    @property
    def values(self):
        """Gets the values of this IndexedField.  # noqa: E501


        :return: The values of this IndexedField.  # noqa: E501
        :rtype: list[object]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this IndexedField.


        :param values: The values of this IndexedField.  # noqa: E501
        :type values: list[object]
        """
        if self.local_vars_configuration.client_side_validation and values is None:  # noqa: E501
            raise ValueError("Invalid value for `values`, must not be `None`")  # noqa: E501

        self._values = values

    @property
    def name(self):
        """Gets the name of this IndexedField.  # noqa: E501


        :return: The name of this IndexedField.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndexedField.


        :param name: The name of this IndexedField.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def value(self):
        """Gets the value of this IndexedField.  # noqa: E501


        :return: The value of this IndexedField.  # noqa: E501
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this IndexedField.


        :param value: The value of this IndexedField.  # noqa: E501
        :type value: object
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def metadata_field(self):
        """Gets the metadata_field of this IndexedField.  # noqa: E501


        :return: The metadata_field of this IndexedField.  # noqa: E501
        :rtype: bool
        """
        return self._metadata_field

    @metadata_field.setter
    def metadata_field(self, metadata_field):
        """Sets the metadata_field of this IndexedField.


        :param metadata_field: The metadata_field of this IndexedField.  # noqa: E501
        :type metadata_field: bool
        """
        if self.local_vars_configuration.client_side_validation and metadata_field is None:  # noqa: E501
            raise ValueError("Invalid value for `metadata_field`, must not be `None`")  # noqa: E501

        self._metadata_field = metadata_field

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndexedField):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, IndexedField):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Pipelines

    Pipelines represent distinct stages in a workflow, like closing a deal or servicing a support ticket. These endpoints provide access to read and modify pipelines in HubSpot. Pipelines support `deals` and `tickets` object types.  ## Pipeline ID validation  When calling endpoints that take pipelineId as a parameter, that ID must correspond to an existing, un-archived pipeline. Otherwise the request will fail with a `404 Not Found` response.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.crm.pipelines.api_client import ApiClient
from hubspot.crm.pipelines.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class PipelineStagesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive(self, object_type, pipeline_id, stage_id, **kwargs):  # noqa: E501
        """Delete a pipeline stage  # noqa: E501

        Delete the pipeline stage identified by `{stageId}` associated with the pipeline identified by `{pipelineId}`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive(object_type, pipeline_id, stage_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """
        kwargs["_return_http_data_only"] = True
        return self.archive_with_http_info(object_type, pipeline_id, stage_id, **kwargs)  # noqa: E501

    def archive_with_http_info(self, object_type, pipeline_id, stage_id, **kwargs):  # noqa: E501
        """Delete a pipeline stage  # noqa: E501

        Delete the pipeline stage identified by `{stageId}` associated with the pipeline identified by `{pipelineId}`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.archive_with_http_info(object_type, pipeline_id, stage_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: None
        """

        local_var_params = locals()

        all_params = ["object_type", "pipeline_id", "stage_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method archive" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `archive`")  # noqa: E501
        # verify the required parameter 'pipeline_id' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_id` when calling `archive`")  # noqa: E501
        # verify the required parameter 'stage_id' is set
        if self.api_client.client_side_validation and local_var_params.get("stage_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `stage_id` when calling `archive`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "pipeline_id" in local_var_params:
            path_params["pipelineId"] = local_var_params["pipeline_id"]  # noqa: E501
        if "stage_id" in local_var_params:
            path_params["stageId"] = local_var_params["stage_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {}

        return self.api_client.call_api(
            "/crm/v3/pipelines/{objectType}/{pipelineId}/stages/{stageId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def create(self, object_type, pipeline_id, pipeline_stage_input, **kwargs):  # noqa: E501
        """Create a pipeline stage  # noqa: E501

        Create a new stage associated with the pipeline identified by `{pipelineId}`. The entire stage object, including its unique ID, will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create(object_type, pipeline_id, pipeline_stage_input, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param pipeline_stage_input: (required)
        :type pipeline_stage_input: PipelineStageInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PipelineStage
        """
        kwargs["_return_http_data_only"] = True
        return self.create_with_http_info(object_type, pipeline_id, pipeline_stage_input, **kwargs)  # noqa: E501

    def create_with_http_info(self, object_type, pipeline_id, pipeline_stage_input, **kwargs):  # noqa: E501
        """Create a pipeline stage  # noqa: E501

        Create a new stage associated with the pipeline identified by `{pipelineId}`. The entire stage object, including its unique ID, will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_with_http_info(object_type, pipeline_id, pipeline_stage_input, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param pipeline_stage_input: (required)
        :type pipeline_stage_input: PipelineStageInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PipelineStage, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "pipeline_id", "pipeline_stage_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method create" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `create`")  # noqa: E501
        # verify the required parameter 'pipeline_id' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_id` when calling `create`")  # noqa: E501
        # verify the required parameter 'pipeline_stage_input' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_stage_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_stage_input` when calling `create`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "pipeline_id" in local_var_params:
            path_params["pipelineId"] = local_var_params["pipeline_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "pipeline_stage_input" in local_var_params:
            body_params = local_var_params["pipeline_stage_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "POST", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            201: "PipelineStage",
        }

        return self.api_client.call_api(
            "/crm/v3/pipelines/{objectType}/{pipelineId}/stages",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_all(self, object_type, pipeline_id, **kwargs):  # noqa: E501
        """Return all stages of a pipeline  # noqa: E501

        Return all the stages associated with the pipeline identified by `{pipelineId}`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all(object_type, pipeline_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponsePipelineStageNoPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_all_with_http_info(object_type, pipeline_id, **kwargs)  # noqa: E501

    def get_all_with_http_info(self, object_type, pipeline_id, **kwargs):  # noqa: E501
        """Return all stages of a pipeline  # noqa: E501

        Return all the stages associated with the pipeline identified by `{pipelineId}`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_all_with_http_info(object_type, pipeline_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponsePipelineStageNoPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "pipeline_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_all" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `get_all`")  # noqa: E501
        # verify the required parameter 'pipeline_id' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_id` when calling `get_all`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "pipeline_id" in local_var_params:
            path_params["pipelineId"] = local_var_params["pipeline_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponsePipelineStageNoPaging",
        }

        return self.api_client.call_api(
            "/crm/v3/pipelines/{objectType}/{pipelineId}/stages",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_by_id(self, object_type, pipeline_id, stage_id, **kwargs):  # noqa: E501
        """Return a pipeline stage by ID  # noqa: E501

        Return the stage identified by `{stageId}` associated with the pipeline identified by `{pipelineId}`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(object_type, pipeline_id, stage_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PipelineStage
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(object_type, pipeline_id, stage_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, object_type, pipeline_id, stage_id, **kwargs):  # noqa: E501
        """Return a pipeline stage by ID  # noqa: E501

        Return the stage identified by `{stageId}` associated with the pipeline identified by `{pipelineId}`.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(object_type, pipeline_id, stage_id, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PipelineStage, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "pipeline_id", "stage_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `get_by_id`")  # noqa: E501
        # verify the required parameter 'pipeline_id' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_id` when calling `get_by_id`")  # noqa: E501
        # verify the required parameter 'stage_id' is set
        if self.api_client.client_side_validation and local_var_params.get("stage_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `stage_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "pipeline_id" in local_var_params:
            path_params["pipelineId"] = local_var_params["pipeline_id"]  # noqa: E501
        if "stage_id" in local_var_params:
            path_params["stageId"] = local_var_params["stage_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "PipelineStage",
        }

        return self.api_client.call_api(
            "/crm/v3/pipelines/{objectType}/{pipelineId}/stages/{stageId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def replace(self, object_type, pipeline_id, stage_id, pipeline_stage_input, **kwargs):  # noqa: E501
        """Replace a pipeline stage  # noqa: E501

        Replace all the properties of an existing pipeline stage with the values provided. The updated stage will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace(object_type, pipeline_id, stage_id, pipeline_stage_input, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param pipeline_stage_input: (required)
        :type pipeline_stage_input: PipelineStageInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PipelineStage
        """
        kwargs["_return_http_data_only"] = True
        return self.replace_with_http_info(object_type, pipeline_id, stage_id, pipeline_stage_input, **kwargs)  # noqa: E501

    def replace_with_http_info(self, object_type, pipeline_id, stage_id, pipeline_stage_input, **kwargs):  # noqa: E501
        """Replace a pipeline stage  # noqa: E501

        Replace all the properties of an existing pipeline stage with the values provided. The updated stage will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.replace_with_http_info(object_type, pipeline_id, stage_id, pipeline_stage_input, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param pipeline_stage_input: (required)
        :type pipeline_stage_input: PipelineStageInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PipelineStage, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "pipeline_id", "stage_id", "pipeline_stage_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method replace" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `replace`")  # noqa: E501
        # verify the required parameter 'pipeline_id' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_id` when calling `replace`")  # noqa: E501
        # verify the required parameter 'stage_id' is set
        if self.api_client.client_side_validation and local_var_params.get("stage_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `stage_id` when calling `replace`")  # noqa: E501
        # verify the required parameter 'pipeline_stage_input' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_stage_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_stage_input` when calling `replace`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "pipeline_id" in local_var_params:
            path_params["pipelineId"] = local_var_params["pipeline_id"]  # noqa: E501
        if "stage_id" in local_var_params:
            path_params["stageId"] = local_var_params["stage_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "pipeline_stage_input" in local_var_params:
            body_params = local_var_params["pipeline_stage_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PUT", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "PipelineStage",
        }

        return self.api_client.call_api(
            "/crm/v3/pipelines/{objectType}/{pipelineId}/stages/{stageId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def update(self, object_type, pipeline_id, stage_id, pipeline_stage_patch_input, **kwargs):  # noqa: E501
        """Update a pipeline stage  # noqa: E501

        Perform a partial update of the pipeline stage identified by `{stageId}` associated with the pipeline identified by `{pipelineId}`. Any properties not included in this update will keep their existing values. The updated stage will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update(object_type, pipeline_id, stage_id, pipeline_stage_patch_input, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param pipeline_stage_patch_input: (required)
        :type pipeline_stage_patch_input: PipelineStagePatchInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PipelineStage
        """
        kwargs["_return_http_data_only"] = True
        return self.update_with_http_info(object_type, pipeline_id, stage_id, pipeline_stage_patch_input, **kwargs)  # noqa: E501

    def update_with_http_info(self, object_type, pipeline_id, stage_id, pipeline_stage_patch_input, **kwargs):  # noqa: E501
        """Update a pipeline stage  # noqa: E501

        Perform a partial update of the pipeline stage identified by `{stageId}` associated with the pipeline identified by `{pipelineId}`. Any properties not included in this update will keep their existing values. The updated stage will be returned in the response.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.update_with_http_info(object_type, pipeline_id, stage_id, pipeline_stage_patch_input, async_req=True)
        >>> result = thread.get()

        :param object_type: (required)
        :type object_type: str
        :param pipeline_id: (required)
        :type pipeline_id: str
        :param stage_id: (required)
        :type stage_id: str
        :param pipeline_stage_patch_input: (required)
        :type pipeline_stage_patch_input: PipelineStagePatchInput
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PipelineStage, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["object_type", "pipeline_id", "stage_id", "pipeline_stage_patch_input"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method update" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'object_type' is set
        if self.api_client.client_side_validation and local_var_params.get("object_type") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `object_type` when calling `update`")  # noqa: E501
        # verify the required parameter 'pipeline_id' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'stage_id' is set
        if self.api_client.client_side_validation and local_var_params.get("stage_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `stage_id` when calling `update`")  # noqa: E501
        # verify the required parameter 'pipeline_stage_patch_input' is set
        if self.api_client.client_side_validation and local_var_params.get("pipeline_stage_patch_input") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `pipeline_stage_patch_input` when calling `update`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "object_type" in local_var_params:
            path_params["objectType"] = local_var_params["object_type"]  # noqa: E501
        if "pipeline_id" in local_var_params:
            path_params["pipelineId"] = local_var_params["pipeline_id"]  # noqa: E501
        if "stage_id" in local_var_params:
            path_params["stageId"] = local_var_params["stage_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        if "pipeline_stage_patch_input" in local_var_params:
            body_params = local_var_params["pipeline_stage_patch_input"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # HTTP header `Content-Type`
        content_types_list = local_var_params.get("_content_type", self.api_client.select_header_content_type(["application/json"], "PATCH", body_params))  # noqa: E501
        if content_types_list:
            header_params["Content-Type"] = content_types_list

        # Authentication setting
        auth_settings = ["oauth2"]  # noqa: E501

        response_types_map = {
            200: "PipelineStage",
        }

        return self.api_client.call_api(
            "/crm/v3/pipelines/{objectType}/{pipelineId}/stages/{stageId}",
            "PATCH",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Companies

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.companies.configuration import Configuration


class ValueWithTimestamp(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"source_id": "str", "source_type": "str", "source_label": "str", "updated_by_user_id": "int", "value": "str", "timestamp": "datetime"}

    attribute_map = {"source_id": "sourceId", "source_type": "sourceType", "source_label": "sourceLabel", "updated_by_user_id": "updatedByUserId", "value": "value", "timestamp": "timestamp"}

    def __init__(self, source_id=None, source_type=None, source_label=None, updated_by_user_id=None, value=None, timestamp=None, local_vars_configuration=None):  # noqa: E501
        """ValueWithTimestamp - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._source_id = None
        self._source_type = None
        self._source_label = None
        self._updated_by_user_id = None
        self._value = None
        self._timestamp = None
        self.discriminator = None

        if source_id is not None:
            self.source_id = source_id
        self.source_type = source_type
        if source_label is not None:
            self.source_label = source_label
        if updated_by_user_id is not None:
            self.updated_by_user_id = updated_by_user_id
        self.value = value
        self.timestamp = timestamp

    @property
    def source_id(self):
        """Gets the source_id of this ValueWithTimestamp.  # noqa: E501


        :return: The source_id of this ValueWithTimestamp.  # noqa: E501
        :rtype: str
        """
        return self._source_id

    @source_id.setter
    def source_id(self, source_id):
        """Sets the source_id of this ValueWithTimestamp.


        :param source_id: The source_id of this ValueWithTimestamp.  # noqa: E501
        :type source_id: str
        """

        self._source_id = source_id

    @property
    def source_type(self):
        """Gets the source_type of this ValueWithTimestamp.  # noqa: E501


        :return: The source_type of this ValueWithTimestamp.  # noqa: E501
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """Sets the source_type of this ValueWithTimestamp.


        :param source_type: The source_type of this ValueWithTimestamp.  # noqa: E501
        :type source_type: str
        """
        if self.local_vars_configuration.client_side_validation and source_type is None:  # noqa: E501
            raise ValueError("Invalid value for `source_type`, must not be `None`")  # noqa: E501

        self._source_type = source_type

    @property
    def source_label(self):
        """Gets the source_label of this ValueWithTimestamp.  # noqa: E501


        :return: The source_label of this ValueWithTimestamp.  # noqa: E501
        :rtype: str
        """
        return self._source_label

    @source_label.setter
    def source_label(self, source_label):
        """Sets the source_label of this ValueWithTimestamp.


        :param source_label: The source_label of this ValueWithTimestamp.  # noqa: E501
        :type source_label: str
        """

        self._source_label = source_label

    @property
    def updated_by_user_id(self):
        """Gets the updated_by_user_id of this ValueWithTimestamp.  # noqa: E501


        :return: The updated_by_user_id of this ValueWithTimestamp.  # noqa: E501
        :rtype: int
        """
        return self._updated_by_user_id

    @updated_by_user_id.setter
    def updated_by_user_id(self, updated_by_user_id):
        """Sets the updated_by_user_id of this ValueWithTimestamp.


        :param updated_by_user_id: The updated_by_user_id of this ValueWithTimestamp.  # noqa: E501
        :type updated_by_user_id: int
        """

        self._updated_by_user_id = updated_by_user_id

    @property
    def value(self):
        """Gets the value of this ValueWithTimestamp.  # noqa: E501


        :return: The value of this ValueWithTimestamp.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ValueWithTimestamp.


        :param value: The value of this ValueWithTimestamp.  # noqa: E501
        :type value: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def timestamp(self):
        """Gets the timestamp of this ValueWithTimestamp.  # noqa: E501


        :return: The timestamp of this ValueWithTimestamp.  # noqa: E501
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this ValueWithTimestamp.


        :param timestamp: The timestamp of this ValueWithTimestamp.  # noqa: E501
        :type timestamp: datetime
        """
        if self.local_vars_configuration.client_side_validation and timestamp is None:  # noqa: E501
            raise ValueError("Invalid value for `timestamp`, must not be `None`")  # noqa: E501

        self._timestamp = timestamp

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ValueWithTimestamp):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ValueWithTimestamp):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Automation Actions V4

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from hubspot.automation.actions.api_client import ApiClient
from hubspot.automation.actions.exceptions import ApiTypeError, ApiValueError  # noqa: F401


class RevisionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_by_id(self, definition_id, revision_id, app_id, **kwargs):  # noqa: E501
        """Gets a revision for a given definition by revision id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id(definition_id, revision_id, app_id, async_req=True)
        >>> result = thread.get()

        :param definition_id: (required)
        :type definition_id: str
        :param revision_id: (required)
        :type revision_id: str
        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: PublicActionRevision
        """
        kwargs["_return_http_data_only"] = True
        return self.get_by_id_with_http_info(definition_id, revision_id, app_id, **kwargs)  # noqa: E501

    def get_by_id_with_http_info(self, definition_id, revision_id, app_id, **kwargs):  # noqa: E501
        """Gets a revision for a given definition by revision id  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_by_id_with_http_info(definition_id, revision_id, app_id, async_req=True)
        >>> result = thread.get()

        :param definition_id: (required)
        :type definition_id: str
        :param revision_id: (required)
        :type revision_id: str
        :param app_id: (required)
        :type app_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(PublicActionRevision, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["definition_id", "revision_id", "app_id"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_by_id" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'definition_id' is set
        if self.api_client.client_side_validation and local_var_params.get("definition_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `definition_id` when calling `get_by_id`")  # noqa: E501
        # verify the required parameter 'revision_id' is set
        if self.api_client.client_side_validation and local_var_params.get("revision_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `revision_id` when calling `get_by_id`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_by_id`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "definition_id" in local_var_params:
            path_params["definitionId"] = local_var_params["definition_id"]  # noqa: E501
        if "revision_id" in local_var_params:
            path_params["revisionId"] = local_var_params["revision_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "PublicActionRevision",
        }

        return self.api_client.call_api(
            "/automation/v4/actions/{appId}/{definitionId}/revisions/{revisionId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )

    def get_page(self, definition_id, app_id, **kwargs):  # noqa: E501
        """Get all revisions for a given definition  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page(definition_id, app_id, async_req=True)
        >>> result = thread.get()

        :param definition_id: (required)
        :type definition_id: str
        :param app_id: (required)
        :type app_id: int
        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CollectionResponsePublicActionRevisionForwardPaging
        """
        kwargs["_return_http_data_only"] = True
        return self.get_page_with_http_info(definition_id, app_id, **kwargs)  # noqa: E501

    def get_page_with_http_info(self, definition_id, app_id, **kwargs):  # noqa: E501
        """Get all revisions for a given definition  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_page_with_http_info(definition_id, app_id, async_req=True)
        >>> result = thread.get()

        :param definition_id: (required)
        :type definition_id: str
        :param app_id: (required)
        :type app_id: int
        :param limit: The maximum number of results to display per page.
        :type limit: int
        :param after: The paging cursor token of the last successfully read resource will be returned as the `paging.next.after` JSON property of a paged response containing more results.
        :type after: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _return_http_data_only: response data without head status code
                                       and headers
        :type _return_http_data_only: bool, optional
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :type _preload_content: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CollectionResponsePublicActionRevisionForwardPaging, status_code(int), headers(HTTPHeaderDict))
        """

        local_var_params = locals()

        all_params = ["definition_id", "app_id", "limit", "after"]
        all_params.extend(["async_req", "_return_http_data_only", "_preload_content", "_request_timeout", "_request_auth", "_content_type", "_headers"])

        for key, val in six.iteritems(local_var_params["kwargs"]):
            if key not in all_params:
                raise ApiTypeError("Got an unexpected keyword argument '%s'" " to method get_page" % key)
            local_var_params[key] = val
        del local_var_params["kwargs"]
        # verify the required parameter 'definition_id' is set
        if self.api_client.client_side_validation and local_var_params.get("definition_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `definition_id` when calling `get_page`")  # noqa: E501
        # verify the required parameter 'app_id' is set
        if self.api_client.client_side_validation and local_var_params.get("app_id") is None:  # noqa: E501
            raise ApiValueError("Missing the required parameter `app_id` when calling `get_page`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if "definition_id" in local_var_params:
            path_params["definitionId"] = local_var_params["definition_id"]  # noqa: E501
        if "app_id" in local_var_params:
            path_params["appId"] = local_var_params["app_id"]  # noqa: E501

        query_params = []
        if local_var_params.get("limit") is not None:  # noqa: E501
            query_params.append(("limit", local_var_params["limit"]))  # noqa: E501
        if local_var_params.get("after") is not None:  # noqa: E501
            query_params.append(("after", local_var_params["after"]))  # noqa: E501

        header_params = dict(local_var_params.get("_headers", {}))

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(["application/json", "*/*"])  # noqa: E501

        # Authentication setting
        auth_settings = ["developer_hapikey"]  # noqa: E501

        response_types_map = {
            200: "CollectionResponsePublicActionRevisionForwardPaging",
        }

        return self.api_client.call_api(
            "/automation/v4/actions/{appId}/{definitionId}/revisions",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_types_map=response_types_map,
            auth_settings=auth_settings,
            async_req=local_var_params.get("async_req"),
            _return_http_data_only=local_var_params.get("_return_http_data_only"),  # noqa: E501
            _preload_content=local_var_params.get("_preload_content", True),
            _request_timeout=local_var_params.get("_request_timeout"),
            collection_formats=collection_formats,
            _request_auth=local_var_params.get("_request_auth"),
        )



# coding: utf-8

"""
    Forms

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.marketing.forms.configuration import Configuration


class DependentFieldFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"range_start": "str", "values": "list[str]", "value": "str", "operator": "str", "range_end": "str"}

    attribute_map = {"range_start": "rangeStart", "values": "values", "value": "value", "operator": "operator", "range_end": "rangeEnd"}

    def __init__(self, range_start=None, values=None, value=None, operator=None, range_end=None, local_vars_configuration=None):  # noqa: E501
        """DependentFieldFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._range_start = None
        self._values = None
        self._value = None
        self._operator = None
        self._range_end = None
        self.discriminator = None

        self.range_start = range_start
        self.values = values
        self.value = value
        self.operator = operator
        self.range_end = range_end

    @property
    def range_start(self):
        """Gets the range_start of this DependentFieldFilter.  # noqa: E501

          # noqa: E501

        :return: The range_start of this DependentFieldFilter.  # noqa: E501
        :rtype: str
        """
        return self._range_start

    @range_start.setter
    def range_start(self, range_start):
        """Sets the range_start of this DependentFieldFilter.

          # noqa: E501

        :param range_start: The range_start of this DependentFieldFilter.  # noqa: E501
        :type range_start: str
        """
        if self.local_vars_configuration.client_side_validation and range_start is None:  # noqa: E501
            raise ValueError("Invalid value for `range_start`, must not be `None`")  # noqa: E501

        self._range_start = range_start

    @property
    def values(self):
        """Gets the values of this DependentFieldFilter.  # noqa: E501

          # noqa: E501

        :return: The values of this DependentFieldFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._values

    @values.setter
    def values(self, values):
        """Sets the values of this DependentFieldFilter.

          # noqa: E501

        :param values: The values of this DependentFieldFilter.  # noqa: E501
        :type values: list[str]
        """
        if self.local_vars_configuration.client_side_validation and values is None:  # noqa: E501
            raise ValueError("Invalid value for `values`, must not be `None`")  # noqa: E501

        self._values = values

    @property
    def value(self):
        """Gets the value of this DependentFieldFilter.  # noqa: E501

          # noqa: E501

        :return: The value of this DependentFieldFilter.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this DependentFieldFilter.

          # noqa: E501

        :param value: The value of this DependentFieldFilter.  # noqa: E501
        :type value: str
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def operator(self):
        """Gets the operator of this DependentFieldFilter.  # noqa: E501

          # noqa: E501

        :return: The operator of this DependentFieldFilter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this DependentFieldFilter.

          # noqa: E501

        :param operator: The operator of this DependentFieldFilter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501
        allowed_values = [
            "eq",
            "neq",
            "contains",
            "doesnt_contain",
            "str_starts_with",
            "str_ends_with",
            "lt",
            "lte",
            "gt",
            "gte",
            "between",
            "not_between",
            "within_time_reverse",
            "within_time",
            "set_any",
            "set_not_any",
            "set_all",
            "set_not_all",
            "set_eq",
            "set_neq",
            "is_not_empty",
        ]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and operator not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `operator` ({0}), must be one of {1}".format(operator, allowed_values))  # noqa: E501

        self._operator = operator

    @property
    def range_end(self):
        """Gets the range_end of this DependentFieldFilter.  # noqa: E501

          # noqa: E501

        :return: The range_end of this DependentFieldFilter.  # noqa: E501
        :rtype: str
        """
        return self._range_end

    @range_end.setter
    def range_end(self, range_end):
        """Sets the range_end of this DependentFieldFilter.

          # noqa: E501

        :param range_end: The range_end of this DependentFieldFilter.  # noqa: E501
        :type range_end: str
        """
        if self.local_vars_configuration.client_side_validation and range_end is None:  # noqa: E501
            raise ValueError("Invalid value for `range_end`, must not be `None`")  # noqa: E501

        self._range_end = range_end

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DependentFieldFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DependentFieldFilter):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CRM Associations

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v4
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.associations.v4.configuration import Configuration


class Paging(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"next": "NextPage", "prev": "PreviousPage"}

    attribute_map = {"next": "next", "prev": "prev"}

    def __init__(self, next=None, prev=None, local_vars_configuration=None):  # noqa: E501
        """Paging - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._next = None
        self._prev = None
        self.discriminator = None

        if next is not None:
            self.next = next
        if prev is not None:
            self.prev = prev

    @property
    def next(self):
        """Gets the next of this Paging.  # noqa: E501


        :return: The next of this Paging.  # noqa: E501
        :rtype: NextPage
        """
        return self._next

    @next.setter
    def next(self, next):
        """Sets the next of this Paging.


        :param next: The next of this Paging.  # noqa: E501
        :type next: NextPage
        """

        self._next = next

    @property
    def prev(self):
        """Gets the prev of this Paging.  # noqa: E501


        :return: The prev of this Paging.  # noqa: E501
        :rtype: PreviousPage
        """
        return self._prev

    @prev.setter
    def prev(self, prev):
        """Sets the prev of this Paging.


        :param prev: The prev of this Paging.  # noqa: E501
        :type prev: PreviousPage
        """

        self._prev = prev

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Paging):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Paging):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicPropertyAssociationFilterBranchFilterBranchesInner(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "filter_branch_type": "str",
        "filter_branches": "list[PublicPropertyAssociationFilterBranchFilterBranchesInner]",
        "filter_branch_operator": "str",
        "filters": "list[PublicPropertyAssociationFilterBranchFiltersInner]",
        "event_type_id": "str",
        "coalescing_refine_by": "PublicFormSubmissionFilterCoalescingRefineBy",
        "operator": "str",
        "object_type_id": "str",
        "property_with_object_id": "str",
        "association_type_id": "int",
        "association_category": "str",
    }

    attribute_map = {
        "filter_branch_type": "filterBranchType",
        "filter_branches": "filterBranches",
        "filter_branch_operator": "filterBranchOperator",
        "filters": "filters",
        "event_type_id": "eventTypeId",
        "coalescing_refine_by": "coalescingRefineBy",
        "operator": "operator",
        "object_type_id": "objectTypeId",
        "property_with_object_id": "propertyWithObjectId",
        "association_type_id": "associationTypeId",
        "association_category": "associationCategory",
    }

    def __init__(
        self,
        filter_branch_type="ASSOCIATION",
        filter_branches=None,
        filter_branch_operator=None,
        filters=None,
        event_type_id=None,
        coalescing_refine_by=None,
        operator=None,
        object_type_id=None,
        property_with_object_id=None,
        association_type_id=None,
        association_category=None,
        local_vars_configuration=None,
    ):  # noqa: E501
        """PublicPropertyAssociationFilterBranchFilterBranchesInner - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._filter_branch_type = None
        self._filter_branches = None
        self._filter_branch_operator = None
        self._filters = None
        self._event_type_id = None
        self._coalescing_refine_by = None
        self._operator = None
        self._object_type_id = None
        self._property_with_object_id = None
        self._association_type_id = None
        self._association_category = None
        self.discriminator = None

        self.filter_branch_type = filter_branch_type
        self.filter_branches = filter_branches
        self.filter_branch_operator = filter_branch_operator
        self.filters = filters
        self.event_type_id = event_type_id
        if coalescing_refine_by is not None:
            self.coalescing_refine_by = coalescing_refine_by
        self.operator = operator
        self.object_type_id = object_type_id
        self.property_with_object_id = property_with_object_id
        self.association_type_id = association_type_id
        self.association_category = association_category

    @property
    def filter_branch_type(self):
        """Gets the filter_branch_type of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The filter_branch_type of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._filter_branch_type

    @filter_branch_type.setter
    def filter_branch_type(self, filter_branch_type):
        """Sets the filter_branch_type of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param filter_branch_type: The filter_branch_type of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type filter_branch_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_branch_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_type`, must not be `None`")  # noqa: E501
        allowed_values = ["ASSOCIATION"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_branch_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_type` ({0}), must be one of {1}".format(filter_branch_type, allowed_values))  # noqa: E501

        self._filter_branch_type = filter_branch_type

    @property
    def filter_branches(self):
        """Gets the filter_branches of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The filter_branches of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: list[PublicPropertyAssociationFilterBranchFilterBranchesInner]
        """
        return self._filter_branches

    @filter_branches.setter
    def filter_branches(self, filter_branches):
        """Sets the filter_branches of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param filter_branches: The filter_branches of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type filter_branches: list[PublicPropertyAssociationFilterBranchFilterBranchesInner]
        """
        if self.local_vars_configuration.client_side_validation and filter_branches is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branches`, must not be `None`")  # noqa: E501

        self._filter_branches = filter_branches

    @property
    def filter_branch_operator(self):
        """Gets the filter_branch_operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The filter_branch_operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._filter_branch_operator

    @filter_branch_operator.setter
    def filter_branch_operator(self, filter_branch_operator):
        """Sets the filter_branch_operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param filter_branch_operator: The filter_branch_operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type filter_branch_operator: str
        """
        if self.local_vars_configuration.client_side_validation and filter_branch_operator is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_branch_operator`, must not be `None`")  # noqa: E501

        self._filter_branch_operator = filter_branch_operator

    @property
    def filters(self):
        """Gets the filters of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The filters of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: list[PublicPropertyAssociationFilterBranchFiltersInner]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param filters: The filters of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type filters: list[PublicPropertyAssociationFilterBranchFiltersInner]
        """
        if self.local_vars_configuration.client_side_validation and filters is None:  # noqa: E501
            raise ValueError("Invalid value for `filters`, must not be `None`")  # noqa: E501

        self._filters = filters

    @property
    def event_type_id(self):
        """Gets the event_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The event_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._event_type_id

    @event_type_id.setter
    def event_type_id(self, event_type_id):
        """Sets the event_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param event_type_id: The event_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type event_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and event_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `event_type_id`, must not be `None`")  # noqa: E501

        self._event_type_id = event_type_id

    @property
    def coalescing_refine_by(self):
        """Gets the coalescing_refine_by of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The coalescing_refine_by of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: PublicFormSubmissionFilterCoalescingRefineBy
        """
        return self._coalescing_refine_by

    @coalescing_refine_by.setter
    def coalescing_refine_by(self, coalescing_refine_by):
        """Sets the coalescing_refine_by of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param coalescing_refine_by: The coalescing_refine_by of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type coalescing_refine_by: PublicFormSubmissionFilterCoalescingRefineBy
        """

        self._coalescing_refine_by = coalescing_refine_by

    @property
    def operator(self):
        """Gets the operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param operator: The operator of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    @property
    def object_type_id(self):
        """Gets the object_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The object_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._object_type_id

    @object_type_id.setter
    def object_type_id(self, object_type_id):
        """Sets the object_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param object_type_id: The object_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type object_type_id: str
        """
        if self.local_vars_configuration.client_side_validation and object_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `object_type_id`, must not be `None`")  # noqa: E501

        self._object_type_id = object_type_id

    @property
    def property_with_object_id(self):
        """Gets the property_with_object_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The property_with_object_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._property_with_object_id

    @property_with_object_id.setter
    def property_with_object_id(self, property_with_object_id):
        """Sets the property_with_object_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param property_with_object_id: The property_with_object_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type property_with_object_id: str
        """
        if self.local_vars_configuration.client_side_validation and property_with_object_id is None:  # noqa: E501
            raise ValueError("Invalid value for `property_with_object_id`, must not be `None`")  # noqa: E501

        self._property_with_object_id = property_with_object_id

    @property
    def association_type_id(self):
        """Gets the association_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The association_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: int
        """
        return self._association_type_id

    @association_type_id.setter
    def association_type_id(self, association_type_id):
        """Sets the association_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param association_type_id: The association_type_id of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type association_type_id: int
        """
        if self.local_vars_configuration.client_side_validation and association_type_id is None:  # noqa: E501
            raise ValueError("Invalid value for `association_type_id`, must not be `None`")  # noqa: E501

        self._association_type_id = association_type_id

    @property
    def association_category(self):
        """Gets the association_category of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501


        :return: The association_category of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :rtype: str
        """
        return self._association_category

    @association_category.setter
    def association_category(self, association_category):
        """Sets the association_category of this PublicPropertyAssociationFilterBranchFilterBranchesInner.


        :param association_category: The association_category of this PublicPropertyAssociationFilterBranchFilterBranchesInner.  # noqa: E501
        :type association_category: str
        """
        if self.local_vars_configuration.client_side_validation and association_category is None:  # noqa: E501
            raise ValueError("Invalid value for `association_category`, must not be `None`")  # noqa: E501

        self._association_category = association_category

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicPropertyAssociationFilterBranchFilterBranchesInner):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicPropertyAssociationFilterBranchFilterBranchesInner):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    CRM Objects

    CRM objects such as companies, contacts, deals, line items, products, tickets, and quotes are standard objects in HubSpot’s CRM. These core building blocks support custom properties, store critical information, and play a central role in the HubSpot application.  ## Supported Object Types  This API provides access to collections of CRM objects, which return a map of property names to values. Each object type has its own set of default properties, which can be found by exploring the [CRM Object Properties API](https://developers.hubspot.com/docs/methods/crm-properties/crm-properties-overview).  |Object Type |Properties returned by default | |--|--| | `companies` | `name`, `domain` | | `contacts` | `firstname`, `lastname`, `email` | | `deals` | `dealname`, `amount`, `closedate`, `pipeline`, `dealstage` | | `products` | `name`, `description`, `price` | | `tickets` | `content`, `hs_pipeline`, `hs_pipeline_stage`, `hs_ticket_category`, `hs_ticket_priority`, `subject` |  Find a list of all properties for an object type using the [CRM Object Properties](https://developers.hubspot.com/docs/methods/crm-properties/get-properties) API. e.g. `GET https://api.hubapi.com/properties/v2/companies/properties`. Change the properties returned in the response using the `properties` array in the request body.  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.objects.configuration import Configuration


class BatchReadInputSimplePublicObjectId(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"properties_with_history": "list[str]", "id_property": "str", "inputs": "list[SimplePublicObjectId]", "properties": "list[str]"}

    attribute_map = {"properties_with_history": "propertiesWithHistory", "id_property": "idProperty", "inputs": "inputs", "properties": "properties"}

    def __init__(self, properties_with_history=None, id_property=None, inputs=None, properties=None, local_vars_configuration=None):  # noqa: E501
        """BatchReadInputSimplePublicObjectId - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._properties_with_history = None
        self._id_property = None
        self._inputs = None
        self._properties = None
        self.discriminator = None

        self.properties_with_history = properties_with_history
        if id_property is not None:
            self.id_property = id_property
        self.inputs = inputs
        self.properties = properties

    @property
    def properties_with_history(self):
        """Gets the properties_with_history of this BatchReadInputSimplePublicObjectId.  # noqa: E501


        :return: The properties_with_history of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :rtype: list[str]
        """
        return self._properties_with_history

    @properties_with_history.setter
    def properties_with_history(self, properties_with_history):
        """Sets the properties_with_history of this BatchReadInputSimplePublicObjectId.


        :param properties_with_history: The properties_with_history of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :type properties_with_history: list[str]
        """
        if self.local_vars_configuration.client_side_validation and properties_with_history is None:  # noqa: E501
            raise ValueError("Invalid value for `properties_with_history`, must not be `None`")  # noqa: E501

        self._properties_with_history = properties_with_history

    @property
    def id_property(self):
        """Gets the id_property of this BatchReadInputSimplePublicObjectId.  # noqa: E501

        When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID.  # noqa: E501

        :return: The id_property of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :rtype: str
        """
        return self._id_property

    @id_property.setter
    def id_property(self, id_property):
        """Sets the id_property of this BatchReadInputSimplePublicObjectId.

        When using a custom unique value property to retrieve records, the name of the property. Do not include this parameter if retrieving by record ID.  # noqa: E501

        :param id_property: The id_property of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :type id_property: str
        """

        self._id_property = id_property

    @property
    def inputs(self):
        """Gets the inputs of this BatchReadInputSimplePublicObjectId.  # noqa: E501


        :return: The inputs of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :rtype: list[SimplePublicObjectId]
        """
        return self._inputs

    @inputs.setter
    def inputs(self, inputs):
        """Sets the inputs of this BatchReadInputSimplePublicObjectId.


        :param inputs: The inputs of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :type inputs: list[SimplePublicObjectId]
        """
        if self.local_vars_configuration.client_side_validation and inputs is None:  # noqa: E501
            raise ValueError("Invalid value for `inputs`, must not be `None`")  # noqa: E501

        self._inputs = inputs

    @property
    def properties(self):
        """Gets the properties of this BatchReadInputSimplePublicObjectId.  # noqa: E501


        :return: The properties of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :rtype: list[str]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this BatchReadInputSimplePublicObjectId.


        :param properties: The properties of this BatchReadInputSimplePublicObjectId.  # noqa: E501
        :type properties: list[str]
        """
        if self.local_vars_configuration.client_side_validation and properties is None:  # noqa: E501
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchReadInputSimplePublicObjectId):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BatchReadInputSimplePublicObjectId):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Lists

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from hubspot.crm.lists.configuration import Configuration


class PublicAdsSearchFilter(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"search_terms": "list[str]", "entity_type": "str", "ad_network": "str", "search_term_type": "str", "filter_type": "str", "operator": "str"}

    attribute_map = {"search_terms": "searchTerms", "entity_type": "entityType", "ad_network": "adNetwork", "search_term_type": "searchTermType", "filter_type": "filterType", "operator": "operator"}

    def __init__(self, search_terms=None, entity_type=None, ad_network=None, search_term_type=None, filter_type="ADS_SEARCH", operator=None, local_vars_configuration=None):  # noqa: E501
        """PublicAdsSearchFilter - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._search_terms = None
        self._entity_type = None
        self._ad_network = None
        self._search_term_type = None
        self._filter_type = None
        self._operator = None
        self.discriminator = None

        self.search_terms = search_terms
        self.entity_type = entity_type
        self.ad_network = ad_network
        self.search_term_type = search_term_type
        self.filter_type = filter_type
        self.operator = operator

    @property
    def search_terms(self):
        """Gets the search_terms of this PublicAdsSearchFilter.  # noqa: E501


        :return: The search_terms of this PublicAdsSearchFilter.  # noqa: E501
        :rtype: list[str]
        """
        return self._search_terms

    @search_terms.setter
    def search_terms(self, search_terms):
        """Sets the search_terms of this PublicAdsSearchFilter.


        :param search_terms: The search_terms of this PublicAdsSearchFilter.  # noqa: E501
        :type search_terms: list[str]
        """
        if self.local_vars_configuration.client_side_validation and search_terms is None:  # noqa: E501
            raise ValueError("Invalid value for `search_terms`, must not be `None`")  # noqa: E501

        self._search_terms = search_terms

    @property
    def entity_type(self):
        """Gets the entity_type of this PublicAdsSearchFilter.  # noqa: E501


        :return: The entity_type of this PublicAdsSearchFilter.  # noqa: E501
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """Sets the entity_type of this PublicAdsSearchFilter.


        :param entity_type: The entity_type of this PublicAdsSearchFilter.  # noqa: E501
        :type entity_type: str
        """
        if self.local_vars_configuration.client_side_validation and entity_type is None:  # noqa: E501
            raise ValueError("Invalid value for `entity_type`, must not be `None`")  # noqa: E501

        self._entity_type = entity_type

    @property
    def ad_network(self):
        """Gets the ad_network of this PublicAdsSearchFilter.  # noqa: E501


        :return: The ad_network of this PublicAdsSearchFilter.  # noqa: E501
        :rtype: str
        """
        return self._ad_network

    @ad_network.setter
    def ad_network(self, ad_network):
        """Sets the ad_network of this PublicAdsSearchFilter.


        :param ad_network: The ad_network of this PublicAdsSearchFilter.  # noqa: E501
        :type ad_network: str
        """
        if self.local_vars_configuration.client_side_validation and ad_network is None:  # noqa: E501
            raise ValueError("Invalid value for `ad_network`, must not be `None`")  # noqa: E501

        self._ad_network = ad_network

    @property
    def search_term_type(self):
        """Gets the search_term_type of this PublicAdsSearchFilter.  # noqa: E501


        :return: The search_term_type of this PublicAdsSearchFilter.  # noqa: E501
        :rtype: str
        """
        return self._search_term_type

    @search_term_type.setter
    def search_term_type(self, search_term_type):
        """Sets the search_term_type of this PublicAdsSearchFilter.


        :param search_term_type: The search_term_type of this PublicAdsSearchFilter.  # noqa: E501
        :type search_term_type: str
        """
        if self.local_vars_configuration.client_side_validation and search_term_type is None:  # noqa: E501
            raise ValueError("Invalid value for `search_term_type`, must not be `None`")  # noqa: E501

        self._search_term_type = search_term_type

    @property
    def filter_type(self):
        """Gets the filter_type of this PublicAdsSearchFilter.  # noqa: E501


        :return: The filter_type of this PublicAdsSearchFilter.  # noqa: E501
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """Sets the filter_type of this PublicAdsSearchFilter.


        :param filter_type: The filter_type of this PublicAdsSearchFilter.  # noqa: E501
        :type filter_type: str
        """
        if self.local_vars_configuration.client_side_validation and filter_type is None:  # noqa: E501
            raise ValueError("Invalid value for `filter_type`, must not be `None`")  # noqa: E501
        allowed_values = ["ADS_SEARCH"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and filter_type not in allowed_values:  # noqa: E501
            raise ValueError("Invalid value for `filter_type` ({0}), must be one of {1}".format(filter_type, allowed_values))  # noqa: E501

        self._filter_type = filter_type

    @property
    def operator(self):
        """Gets the operator of this PublicAdsSearchFilter.  # noqa: E501


        :return: The operator of this PublicAdsSearchFilter.  # noqa: E501
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """Sets the operator of this PublicAdsSearchFilter.


        :param operator: The operator of this PublicAdsSearchFilter.  # noqa: E501
        :type operator: str
        """
        if self.local_vars_configuration.client_side_validation and operator is None:  # noqa: E501
            raise ValueError("Invalid value for `operator`, must not be `None`")  # noqa: E501

        self._operator = operator

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(lambda x: convert(x), value))
            elif isinstance(value, dict):
                result[attr] = dict(map(lambda item: (item[0], convert(item[1])), value.items()))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PublicAdsSearchFilter):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PublicAdsSearchFilter):
            return True

        return self.to_dict() != other.to_dict()
